@@ -1,16 +1,16 @@
 from zeno.api import (
-    distill,
     DistillReturn,
-    inference,
     InferenceReturn,
-    metric,
     MetricReturn,
-    model,
     ModelReturn,
     ZenoOptions,
     ZenoParameters,
+    distill,
+    inference,
+    metric,
+    model,
 )
-from zeno.runner import zeno
+from zeno.runner import get_server, zeno
 
 __all__ = [
     "DistillReturn",
@@ -19,6 +19,7 @@ __all__ = [
     "ModelReturn",
     "ZenoOptions",
     "ZenoParameters",
+    "get_server",
     "distill",
     "inference",
     "metric",
